@@ -25,6 +25,7 @@ import getpass
 from types import StringType
 import string
 import pwd
+import itertools
 
 from calculate.lib.cl_lang import setLocalTranslate
 
@@ -557,11 +558,16 @@ def isBootstrapDataOnly(user_dir):
     а так же настроенные симлинки на .face, skel
     """
     from calculate.lib.utils.files import find
-    skel_files = set([x for x in find('/etc/skel', fullpath=False)
+    max_diff = 10
+    skel_files = set([x for x in find('/etc/skel', onefilesystem=True,
+                                      fullpath=False)
                   if not x.startswith(".calculate")])
-    user_files = set([x for x in find(user_dir, fullpath=False)
-                  if not x.startswith(".calculate")])
-    return not len(user_files - skel_files) > 10
+    user_data = find(user_dir, onefilesystem=True, fullpath=False)
+    user_files = itertools.islice((x for x in user_data
+                                   if not x.startswith(".calculate")),
+                 len(skel_files)+max_diff)
+    user_files = set(user_files)
+    return not len(user_files - skel_files) > max_diff
 
 
 def getPortageUidGid():
